********************************************************************************
Citing
********************************************************************************

If you use COMPAS FAB in a project, please use the following citation:

.. code-block:: none

    @misc{compas-fab,
        title={{COMPAS~FAB}: Robotic fabrication package for the COMPAS Framework},
        author={
            Rust, R. and
            Casas, G. and
            Parascho, S. and
            Jenny, D. and
            D\"{o}rfler, K. and
            Helmreich, M. and
            Gandia, A. and
            Ma, Z. and
            Ariza, I. and
            Pacher, M. and
            Lytle, B. and
            Huang, Y.
            },
        howpublished={https://github.com/compas-dev/compas\_fab/},
        note={Gramazio Kohler Research, ETH Z\"{u}rich},
        year={2018},
        doi={10.5281/zenodo.3469478},
        url={https://doi.org/10.5281/zenodo.3469478},
    }

Authors
=======

* Gramazio Kohler Research `@gramaziokohler <https://github.com/gramaziokohler>`_
* Romana Rust <rust@arch.ethz.ch> `@romanarust <https://github.com/romanarust>`_
* Gonzalo Casas <casas@arch.ethz.ch> `@gonzalocasas <https://github.com/gonzalocasas>`_
* Stefana Parascho <parascho@arch.ethz.ch> `@stefanaparascho <https://github.com/stefanaparascho>`_
* David Jenny <jenny@arch.ethz.ch> `@DavidJenny <https://github.com/DavidJenny>`_
* Kathrin Dörfler <doerfler@arch.ethz.ch> `@kathrindoerfler <https://github.com/kathrindoerfler>`_
* Matthias Helmreich <helmreich@arch.ethz.ch> `@mhelmrei <https://github.com/mhelmrei>`_
* Augusto Gandia <gandia@arch.ethz.ch> `@augustogandia <https://github.com/augustogandia>`_
* Zhao Ma <ma@arch.ethz.ch> `@xarthurx <https://github.com/xarthurx>`_
* Inés Ariza <ariza@arch.ethz.ch> `@inesariza <https://github.com/inesariza>`_
* Matteo Pacher <pacher@arch.ethz.ch> `@matteo-pacher <https://github.com/matteo-pacher>`_
* Beverly Lytle <lytle@arch.ethz.ch> `@beverlylytle <https://github.com/beverlylytle>`_
* Yijiang Huang <yijiangh@mit.edu> `@yijiangh <https://github.com/yijiangh>`_
